@@ -9,13 +9,13 @@ Linux::SysInfo - Perl interface to the sysinfo(2) Linux system call.
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
 our $VERSION;
 BEGIN {
- $VERSION = '0.10';
+ $VERSION = '0.11';
 }
 
 =head1 SYNOPSIS
@@ -27,13 +27,15 @@ BEGIN {
 
 =head1 DESCRIPTION
 
-This module is a wrapper around the sysinfo(2) Linux system call. It gives information about the current uptime, load average, memory usage and processes running. Other systems have also this system call (e.g. Solaris), but in most cases the returned information is different.
+This module is a wrapper around the C<sysinfo(2)> Linux system call.
+It gives information about the current uptime, load average, memory usage and processes running.
+Other systems have also this system call (e.g. Solaris), but in most cases the returned information is different.
 
 =head1 CONSTANTS
 
 =head2 C<LS_HAS_EXTENDED>
 
-This constant is set to 1 if your kernel supports the three extended fields C<totalhigh>, C<freehigh> and C<mem_unit> ; and to 0 otherwise.
+This constant is set to C<1> if your kernel supports the three extended fields C<totalhigh>, C<freehigh> and C<mem_unit> ; and to C<0> otherwise.
 
 =head1 FUNCTIONS
 
@@ -46,61 +48,87 @@ BEGIN {
 
 =head2 C<sysinfo>
 
-This function takes no argument. It returns undef on failure or a hash reference whose keys are the members name of the struct sysinfo on success :
+This function takes no argument.
+It returns C<undef> on failure or a hash reference whose keys are the members name of the C<struct sysinfo> on success :
 
 =over 4
 
-=item C<uptime>
+=item *
+
+C<uptime>
 
 Seconds elapsed since the system booted.
 
-=item C<load1>, C<load5>, C<load15>
+=item *
+
+C<load1>, C<load5>, C<load15>
 
 1, 5 and 15 minutes load average.
 
-=item C<totalram>
+=item *
+
+C<totalram>
 
 Total usable main memory size.
 
-=item C<freeram>
+=item *
+
+C<freeram>
 
 Available memory size.
 
-=item C<sharedram>
+=item *
+
+C<sharedram>
 
 Amount of shared memory.
 
-=item C<bufferram>
+=item *
+
+C<bufferram>
 
 Memory used by buffers.
 
-=item C<totalswap>
+=item *
+
+C<totalswap>
 
 Total swap space size.
 
-=item C<freeswap>
+=item *
+
+C<freeswap>
 
 Swap space still available.
 
-=item C<procs>
+=item *
+
+C<procs>
 
 Number of current processes.
 
 =back
 
-Prior to Linux 2.3.23 on i386 and 2.3.48 on all other architectures, the memory sizes were given in bytes. Since then, the following members are also available and all the memory sizes are given as multiples of mem_unit bytes :
+Prior to Linux 2.3.23 on i386 and 2.3.48 on all other architectures, the memory sizes were given in bytes.
+Since then, the following members are also available and all the memory sizes are given as multiples of C<mem_unit> bytes :
 
 =over 4
 
-=item C<totalhigh>
+=item *
+
+C<totalhigh>
 
 Total high memory size.
 
-=item C<freehigh>
+=item *
+
+C<freehigh>
 
 Available high memory size.
 
-=item C<mem_unit>
+=item *
+
+C<mem_unit>
 
 Memory unit size in bytes.
 
@@ -108,7 +136,8 @@ Memory unit size in bytes.
 
 =head1 EXPORT
 
-The only function of this module, C<sysinfo>, and the constant C<LS_HAS_EXTENDED> are only exported on request. Functions are also exported by the C<:funcs> tag, and constants by C<:consts>.
+The only function of this module, C<sysinfo>, and the constant C<LS_HAS_EXTENDED> are only exported on request.
+Functions are also exported by the C<:funcs> tag, and constants by C<:consts>.
 
 =cut
 
@@ -128,6 +157,10 @@ If you upgrade your kernel to a greater version than 2.3.23 on i386 or 2.3.48 on
 
 Moreover, since the perl hash function has changed after the 5.6 version, you will also need to recompile the module if you upgrade your perl from a version earlier than 5.6.
 
+=head1 DEPENDENCIES
+
+L<perl> 5.6.
+
 =head1 SEE ALSO
 
 The C<sysinfo(2)> man page.
@@ -142,15 +175,12 @@ L<BSD::getloadavg> : Wrapper to the C<getloadavg(3)> BSD system call.
 
 Vincent Pit, C<< <perl at profvince.com> >>, L<http://www.profvince.com>.
 
-You can contact me by mail or on #perl @ FreeNode (vincent or Prof_Vince).
+You can contact me by mail or on C<irc.perl.org> (vincent).
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-linux-sysinfo at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Linux-SysInfo>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Please report any bugs or feature requests to C<bug-linux-sysinfo at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Linux-SysInfo>.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -158,9 +188,11 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Linux::SysInfo
 
+Tests code coverage report is available at L<http://www.profvince.com/perl/cover/Linux-SysInfo>.
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2008 Vincent Pit, all rights reserved.
+Copyright 2007-2009 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
